@@ -312,12 +312,18 @@ GList* mame_gamelist_get_roms_glist (MameGamelist *gl) {
 
 GList* mame_gamelist_get_categories_glist (MameGamelist *gl) {
 	g_return_val_if_fail (gl != NULL, NULL);
+
+	g_return_val_if_fail (gl->priv->categories != NULL, NULL);
+	g_return_val_if_fail (g_list_length (gl->priv->categories) > 0, NULL);
 	
 	return gl->priv->categories;
 }
 
 GList* mame_gamelist_get_versions_glist (MameGamelist *gl) {
 	g_return_val_if_fail (gl != NULL, NULL);
+
+	g_return_val_if_fail (gl->priv->versions != NULL, NULL);
+	g_return_val_if_fail (g_list_length (gl->priv->versions) > 0, NULL);
 	
 	return gl->priv->versions;
 }
@@ -434,14 +440,18 @@ gboolean mame_gamelist_load (MameGamelist *gl)
 				fclose (gamelist);
 				return FALSE;
 			}
-			if (g_ascii_strtod (tmp_array[2], NULL) < GAMELIST_DEFINED_VERSION)
+			/* While we use a gamelist version number with a decimal
+			   point, we need to use the locale-sensitive strtod,
+			   rather than g_ascii_strtod so that locales using a
+			   comma for the decimal point work correctly */
+			if (strtod (tmp_array[2], NULL) < GAMELIST_DEFINED_VERSION)
 			{
 				gl->priv->version = g_strdup ("too old");
 				g_strfreev (tmp_array);
 				fclose (gamelist);
 				return FALSE;
 			}
-			if (g_ascii_strtod (tmp_array[2], NULL) > GAMELIST_DEFINED_VERSION)
+			if (strtod (tmp_array[2], NULL) > GAMELIST_DEFINED_VERSION)
 			{
 				gl->priv->version = g_strdup ("unknown");
 				g_strfreev (tmp_array);
